summaryrefslogtreecommitdiff
path: root/nuttx/configs/dk-tm4c129x/include/board.h
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/dk-tm4c129x/include/board.h')
-rw-r--r--nuttx/configs/dk-tm4c129x/include/board.h30
1 files changed, 24 insertions, 6 deletions
diff --git a/nuttx/configs/dk-tm4c129x/include/board.h b/nuttx/configs/dk-tm4c129x/include/board.h
index 7df3b08eb..aacdda3b2 100644
--- a/nuttx/configs/dk-tm4c129x/include/board.h
+++ b/nuttx/configs/dk-tm4c129x/include/board.h
@@ -108,14 +108,14 @@
* --- ------------ -----------------
*/
/* LED index values for use with tm4c_setled() */
#define BOARD_LED_R 0
#define BOARD_LED_G 1
#define BOARD_LED_B 2
#define BOARD_NLEDS 3
/* LED bits for use with tm4c_setleds() */
#define BOARD_LED_R_BIT (1 << BOARD_LED_R)
#define BOARD_LED_G_BIT (1 << BOARD_LED_G)
@@ -244,7 +244,7 @@
void tiva_boardinitialize(void);
/************************************************************************************
- * Name: tm4c_ledinit, tm4c_setled, and tm4c_setleds
+ * Name: tiva_ledinit, tiva_setled, and tiva_setleds
*
* Description:
* If CONFIG_ARCH_LEDS is defined, then NuttX will control the on-board LED. If
@@ -254,9 +254,27 @@ void tiva_boardinitialize(void);
************************************************************************************/
#ifndef CONFIG_ARCH_LEDS
-void tm4c_ledinit(void);
-void tm4c_setled(int led, bool ledon);
-void tm4c_setleds(uint8_t ledset);
+void tiva_ledinit(void);
+void tiva_setled(int led, bool ledon);
+void tiva_setleds(uint8_t ledset);
+#endif
+
+/************************************************************************************
+ * Name: tiva_tmp100_initialize
+ *
+ * Description:
+ * Initialize and register the TMP-100 Temperature Sensor driver.
+ *
+ * Input parameters:
+ * devpath - The full path to the driver to register. E.g., "/dev/temp0"
+ *
+ * Returned Value:
+ * Zero (OK) on success; a negated errno value on failure.
+ *
+ ************************************************************************************/
+
+#if defined(CONFIG_I2C) && defined(CONFIG_I2C_LM75) && defined(CONFIG_STM32_I2C1)
+int tiva_tmp100_initialize(FAR const char *devpath);
#endif
#endif /* __ASSEMBLY__ */
@@ -108,14 +108,14 @@
* --- ------------ -----------------
*/
-/* LED index values for use with tm4c_setled() */
+/* LED index values for use with tiva_setled() */
#define BOARD_LED_R 0
#define BOARD_LED_G 1
@@ -108,14 +108,14 @@
#define BOARD_LED_B 2
#define BOARD_NLEDS 3
-/* LED bits for use with tm4c_setleds() */
+/* LED bits for use with tiva_setleds() */
#define BOARD_LED_R_BIT (1 << BOARD_LED_R)
#define BOARD_LED_G_BIT (1 << BOARD_LED_G)